#include "usecurses.h"

struct termios tattr, saved_attributes;

void donecurses()
{
    tcsetattr (STDIN_FILENO, TCSANOW, &saved_attributes);
}

void initcurses() 
{ 
	setvbuf(stdout, NULL, _IONBF, 0);

    /* Save the terminal attributes so we can restore them later. */
    tcgetattr (STDIN_FILENO, &saved_attributes);
    /* Set the funny terminal modes. */
    tcgetattr (STDIN_FILENO, &tattr);
    tattr.c_lflag &= ~(ICANON|ECHO); /* Clear ICANON and ECHO. */
    tattr.c_cc[VMIN] = 1;
    tattr.c_cc[VTIME] = 0;
    tcsetattr (STDIN_FILENO, TCSAFLUSH, &tattr);
  
	atexit(donecurses);
}

char *strlwr(char *string)
{
	char *temp = string;
	
	while(*temp)
	{
		*temp = tolower(*temp);
		if(*temp=='')*temp='';
		if(*temp=='')*temp='';
		if(*temp=='')*temp='';
		temp++;
	}	
	
	return string;
}

char *strupr(char *string)
{
	char *temp = string;
	
	while(*temp)
	{
		*temp = toupper(*temp);
		if(*temp=='')*temp='';
		if(*temp=='')*temp='';
		if(*temp=='')*temp='';
		temp++;
	}	
	
	return string;
}

int strnicmp(const char *eka, const char *toka, long Max)
{
    while(Max--)
    {
    	char ch1 = toupper(*eka);
    	char ch2 = toupper(*toka);
    	if(ch1 < ch2)return -1;
    	if(ch1 > ch2)return 1;
    	if(!ch1)break;
    	eka++;
    	toka++;
    }
    return 0;
}

#define stricmp(a,b) strnicmp((a),(b), 0x7FFFFFFFL)

const char *strscan(const char *str, char Ch)
{
	while(*str)
	{
		if(Ch == *str)return str;
		str++;
	}
	return NULL;
}

char *strccat(char *Dest, char Ch)
{
	register int d=strlen(Dest);
	
	Dest[d] = Ch;
	Dest[d+1] = '\0';
	
	return Dest;
}

void Error(char *Where)
{
 	printf("\33[0;1;31mLaiva: %s() error %d `\33[37m%s\33[31m'\33[m\n", Where, errno, sys_errlist[errno]);
	exit(EXIT_FAILURE);
}

unsigned char TextAttr = 255;

void SetAttr(unsigned char b)
{
	if(b == TextAttr)return;
	TextAttr = b;

	fprintf(stdout, "\33[");

	if(b != 7)
	{
		putchar('0');

		if(b & 0x80)printf(";5");
		if(b &    8)printf(";1");

		switch(b & 0x70)
		{
			case 0x10: printf(";44"); break;
			case 0x20: printf(";42"); break;
			case 0x30: printf(";46"); break;
			case 0x40: printf(";41"); break;
			case 0x50: printf(";45"); break;
			case 0x60: printf(";43"); break;
			case 0x70: printf(";47");
		}

		switch(b & 7)
		{
			case 0: printf(";30"); break;
			case 1: printf(";34"); break;
			case 2: printf(";32"); break;
			case 3: printf(";36"); break;
			case 4: printf(";31"); break;
			case 5: printf(";35"); break;
			case 6: printf(";33");
		}
	}
	putchar('m');
}
